@@ -28,6 +28,8 @@ typedef enum {
   FILTER_ERROR_IS_AUDIO,
   FILTER_ERROR_IS_SCRAP_FILE,
   FILTER_ERROR_MISSING_CHANNEL,
+  FILTER_ERROR_TEMPLATE_MISMATCH,
+  FILTER_ERROR_MEMORY_ERROR,
 
   /// values >= 512 are info
   FILTER_INFO_REINITED=512
@@ -47,6 +49,7 @@ weed_plant_t *get_enabled_channel (weed_plant_t *inst, gint which, gboolean is_i
 weed_plant_t *get_mandatory_channel (weed_plant_t *filter, gint which, gboolean is_in); ///< for FILTER_CLASS
 gboolean weed_filter_is_resizer(weed_plant_t *filt);
 gboolean weed_instance_is_resizer(weed_plant_t *filt);
+weed_plant_t *weed_instance_get_filter(weed_plant_t *inst);
 
 gboolean is_audio_channel_in(weed_plant_t *inst, int chnum);
 gboolean has_video_chans_in(weed_plant_t *filter, gboolean count_opt);
@@ -56,13 +59,19 @@ gboolean has_video_chans_out(weed_plant_t *filter, gboolean count_opt);
 gboolean has_audio_chans_out(weed_plant_t *filter, gboolean count_opt);
 gboolean is_pure_audio(weed_plant_t *filter_or_instance, gboolean count_opt); ///< TRUE if audio in or out and no vid in/out
 
+boolean has_audio_filters(boolean analysers_only);
+boolean has_video_filters(boolean analysers_only);
+
+#ifdef HAS_LIVES_EFFECTS_H
 lives_fx_cat_t weed_filter_categorise (weed_plant_t *pl, int in_channels, int out_channels);
 lives_fx_cat_t weed_filter_subcategorise (weed_plant_t *pl, lives_fx_cat_t category, gboolean count_opt);
+#endif
+
 gboolean has_usable_palette(weed_plant_t *chantmpl);
 int check_weed_palette_list (int *palette_list, int num_palettes, int palette);
 
-void weed_call_init_func(weed_plant_t *instance);
-void weed_call_deinit_func(weed_plant_t *instance);
+int weed_call_init_func(weed_plant_t *instance);
+int weed_call_deinit_func(weed_plant_t *instance);
 
 gchar *cd_to_plugin_dir(weed_plant_t *filter);
 gboolean weed_init_effect(int hotkey); ///< hotkey starts at 1
@@ -71,13 +80,14 @@ weed_plant_t *weed_instance_from_filter(weed_plant_t *filter);
 void weed_instance_ref(weed_plant_t *inst);
 void weed_instance_unref(weed_plant_t *inst);
 void weed_in_parameters_free (weed_plant_t *inst);
-lives_filter_error_t weed_reinit_effect (weed_plant_t *inst, gboolean deinit_first);
+lives_filter_error_t weed_reinit_effect (weed_plant_t *inst);
 void weed_reinit_all(void);
 
 
 int weed_flagset_array_count(weed_plant_t **array, gboolean set_readonly);
 
 int num_in_params(weed_plant_t *, gboolean count_reinits, gboolean count_variable);
+int num_out_params(weed_plant_t *);
 weed_plant_t *weed_inst_in_param (weed_plant_t *inst, int param_num, gboolean skip_hidden);
 gboolean is_hidden_param(weed_plant_t *plant, int i);
 int get_nth_simple_param(weed_plant_t *plant, int pnum);
@@ -94,8 +104,6 @@ gboolean weed_parameter_has_variable_elements_strict(weed_plant_t *inst, weed_pl
 gboolean interpolate_param(weed_plant_t *inst, int i, void *pchain, weed_timecode_t tc);
 gboolean interpolate_params(weed_plant_t *inst, void **pchains, weed_timecode_t tc);
 
-void update_visual_params(lives_rfx_t *rfx, gboolean update_hidden);
-
 gboolean weed_plant_serialise(int fd, weed_plant_t *plant, unsigned char **mem);
 weed_plant_t *weed_plant_deserialise(int fd, unsigned char **mem);
 
@@ -103,6 +111,9 @@ weed_plant_t *weed_plant_deserialise(int fd, unsigned char **mem);
 /// record a parameter value change in our event_list
 void rec_param_change(weed_plant_t *inst, int pnum);
 
+// copy values for "copy_value_to" params
+int set_copy_to(weed_plant_t *inst, int pnum, boolean update);
+
 weed_plant_t *get_textparm();
 
 void weed_set_blend_factor(int hotkey);
@@ -117,9 +128,14 @@ int get_next_free_key(void); ///< next free "key" for the multitrack system
 void weed_deinit_all(gboolean shutdown); ///< deinit all active effects
 
 weed_plant_t *weed_apply_effects (weed_plant_t **layers, weed_plant_t *filter_map, weed_timecode_t tc, int opwidth, int opheight, void ***pchains);
-lives_filter_error_t weed_apply_instance (weed_plant_t *inst, weed_plant_t *init_event, weed_plant_t **layers, int opwidth, int opheight, weed_timecode_t tc);
-void weed_apply_audio_effects (weed_plant_t *filter_map, float **abuf, int nbtracks, int nchans, int64_t nsamps, gdouble arate, weed_timecode_t tc, double *vis);
-lives_filter_error_t weed_apply_audio_instance (weed_plant_t *init_event, float **abuf, int nbtracks, int nchans, int64_t nsamps, gdouble arate, int aint, weed_timecode_t tc, double *vis);
+lives_filter_error_t weed_apply_instance (weed_plant_t *inst, weed_plant_t *init_event, weed_plant_t **layers, 
+					  int opwidth, int opheight, weed_timecode_t tc);
+void weed_apply_audio_effects (weed_plant_t *filter_map, float **abuf, int nbtracks, int nchans, int64_t nsamps, gdouble arate, 
+			       weed_timecode_t tc, double *vis);
+void weed_apply_audio_effects_rt(float **abuf, int nchans, int64_t nsamps, gdouble arate, weed_timecode_t tc, boolean analysers_only);
+
+lives_filter_error_t weed_apply_audio_instance (weed_plant_t *init_event, float **abuf, int nbtracks, int nchans, int64_t nsamps, 
+						gdouble arate, weed_timecode_t tc, double *vis);
 
 gboolean weed_generator_start (weed_plant_t *inst);
 weed_plant_t *weed_layer_new_from_generator (weed_plant_t *inst, weed_timecode_t tc);
@@ -142,7 +158,11 @@ gint rte_keymode_get_filter_idx(gint key, gint mode); ///< returns filter_class
 gchar *rte_keymode_get_filter_name (gint key, gint mode); ///< returns name of filter_class bound to key/mode (or "")
 gchar *rte_keymode_get_plugin_name(gint key, gint mode); ///< returns name of plugin package containing filter_class (or "")
 gchar *rte_keymode_get_type (gint key, gint mode, gboolean get_subtype); ///< returns a string filter/instance type (or "")
+
+#ifdef HAS_LIVES_EFFECTS_H
 lives_fx_cat_t rte_keymode_get_category (gint key, gint mode);
+#endif
+
 weed_plant_t *rte_keymode_get_instance(gint key, gint mode); ///< returns filter_instance bound to key/mode (or NULL)
 weed_plant_t *rte_keymode_get_filter(gint key, gint mode); ///< returns filter_class bound to key/mode (or NULL)
 
@@ -218,7 +238,7 @@ void weed_add_plant_flags (weed_plant_t *plant, int flags);
 void update_host_info (weed_plant_t *inst);
 
 /// add default filler values to a parameter or pchange.
-void fill_param_vals_to (weed_plant_t *paramtmpl, weed_plant_t *param, int pnum, int hint, int index);
+void fill_param_vals_to (weed_plant_t *param, weed_plant_t *ptmpl, int fill_slot);
 
 
 // some general utilities
