@@ -11,6 +11,7 @@
 #ifdef ENABLE_JACK
 #include "callbacks.h"
 #include "support.h"
+#include "effects-weed.h"
 
 #define afile mainw->files[jackd->playing_file]
 
@@ -597,16 +598,19 @@ static int audio_process (nframes_t nframes, void *arg) {
 		}
 	      }
 
-	      // get back interleaved float fbuffer; rate and channels should match
+	      // get back non-interleaved float fbuffer; rate and channels should match
 
 	      for (i=0;i<jackd->num_output_channels;i++) {
 		if (pl_error) sample_silence_dS(out_buffer[i], nframes);
 		else {
-		  sample_move_float_float(out_buffer[i], fbuffer + i, numFramesToWrite,
-					  jackd->num_output_channels, vol);
+		   lives_memcpy(out_buffer[i],fbuffer+(i*numFramesToWrite),numFramesToWrite*sizeof(float));
 		}
+	      }
 
-		
+	      if (!pl_error&&has_audio_filters(FALSE)) {
+		gint64 tc=jackd->audio_ticks+(gint64)(jackd->frames_written/(gdouble)jackd->sample_out_rate*U_SEC);
+	       // apply any audio effects with in_channels
+		weed_apply_audio_effects_rt(out_buffer,jackd->num_output_channels,numFramesToWrite,jackd->sample_out_rate,tc,FALSE);
 	      }
 
 	      if (mainw->record&&mainw->ascrap_file!=-1&&mainw->playing_file>0) {
@@ -623,8 +627,15 @@ static int audio_process (nframes_t nframes, void *arg) {
 	    else {
 	      for (i=0;i<jackd->num_output_channels;i++) {
 		sample_move_d16_float(out_buffer[i], cache_buffer->buffer16[0] + i, numFramesToWrite, 
-				      jackd->num_output_channels, afile->signed_endian&AFORM_UNSIGNED, vol);
+				      jackd->num_output_channels, afile->signed_endian&AFORM_UNSIGNED, FALSE, vol);
 	      }
+
+	      if (has_audio_filters(FALSE)&&jackd->playing_file!=mainw->ascrap_file) {
+		gint64 tc=jackd->audio_ticks+(gint64)(jackd->frames_written/(gdouble)jackd->sample_out_rate*U_SEC);
+	       // apply any audio effects with in_channels
+		weed_apply_audio_effects_rt(out_buffer,jackd->num_output_channels,numFramesToWrite,jackd->sample_out_rate,tc,FALSE);
+	      }
+
 	    }
 	    
 	    if (jackd->astream_fd!=-1) {
@@ -672,12 +683,12 @@ static int audio_process (nframes_t nframes, void *arg) {
 		  }
 		  if (jackd->num_output_channels==1) bysize=2;
 		  while (nbytes>0) {
-		    memcpy(xbuf+tsize,inbuf,bysize);
+		    lives_memcpy(xbuf+tsize,inbuf,bysize);
 		    tsize+=bysize;
 		    nbytes-=bysize;
 		    if (bysize==2) {
 		      // duplicate mono channel
-		      memcpy(xbuf+tsize,inbuf,bysize);
+		      lives_memcpy(xbuf+tsize,inbuf,bysize);
 		      tsize+=bysize;
 		      nbytes-=bysize;
 		      inbuf+=bysize;
@@ -736,12 +747,12 @@ static int audio_process (nframes_t nframes, void *arg) {
 		
 		if (jackd->num_output_channels==1) bysize=2;
 		while (nbytes>0) {
-		  memcpy(xbuf+tsize,inbuf,bysize);
+		  lives_memcpy(xbuf+tsize,inbuf,bysize);
 		  tsize+=bysize;
 		  nbytes-=bysize;
 		  if (bysize==2) {
 		    // duplicate mono channel
-		    memcpy(xbuf+tsize,inbuf,bysize);
+		    lives_memcpy(xbuf+tsize,inbuf,bysize);
 		    tsize+=bysize;
 		    nbytes-=bysize;
 		    inbuf+=bysize;
@@ -925,31 +936,59 @@ static int audio_read (nframes_t nframes, void *arg) {
 
   jack_driver_t* jackd = (jack_driver_t*)arg;
   float *in_buffer[jackd->num_input_channels];
-  float out_scale=(float)jackd->sample_in_rate/(float)afile->arate;
-  int out_unsigned=afile->signed_endian&AFORM_UNSIGNED;
+  float out_scale;
+  int out_unsigned;
   int i;
   int64_t frames_out;
 
   size_t rbytes;
 
+  if (mainw->playing_file<0&&prefs->audio_src==AUDIO_SRC_EXT) return 0; 
+
   if (mainw->effects_paused) return 0; // pause during record
 
   if (mainw->rec_samples==0) return 0; // wrote enough already, return until main thread stop
 
-  frames_out=(int64_t)((gdouble)nframes/out_scale+1.);
-  rbytes=frames_out*afile->achans*afile->asampsize/8;
-
   for (i=0;i<jackd->num_input_channels;i++) {
     in_buffer[i] = (float *) jack_port_get_buffer(jackd->input_port[i], nframes);
   }
 
-  rbytes=audio_read_inner(jackd,in_buffer,jackd->playing_file,nframes,out_scale,mainw->jackd_read->reverse_endian,
-			   out_unsigned,rbytes);
-
   jackd->frames_written+=nframes;
 
-  if (mainw->record&&(prefs->rec_opts&REC_EXT_AUDIO)&&mainw->ascrap_file!=-1&&mainw->playing_file>0) {
+  if (prefs->audio_src==AUDIO_SRC_EXT&&(jackd->playing_file==-1||jackd->playing_file==mainw->ascrap_file)) {
+    // TODO - dont apply filters when doing ext window grab, or voiceover
+
+    // in this case we read external audio, but maybe not record it
+    // we may wish to analyse the audio for example
+
+    if (has_audio_filters(TRUE)) {
+	gint64 tc=jackd->audio_ticks+(gint64)(jackd->frames_written/(gdouble)jackd->sample_in_rate*U_SEC);
+	// apply any audio effects with in_channels and no out_channels
+	weed_apply_audio_effects_rt(in_buffer,jackd->num_input_channels,nframes,jackd->sample_in_rate,tc,TRUE);
+    }
+
+
+  }
+
+  if (jackd->playing_file==-1||(mainw->record&&mainw->record_paused)) {
+    return 0;
+  }
+
+  if (jackd->playing_file==-1) out_scale=1.0; // just listening
+  else out_scale=(float)jackd->sample_in_rate/(float)afile->arate;
+  
+  out_unsigned=afile->signed_endian&AFORM_UNSIGNED;
+  
+  frames_out=(int64_t)((gdouble)nframes/out_scale+1.);
+  rbytes=frames_out*afile->achans*afile->asampsize/8;
+  
+  rbytes=audio_read_inner(jackd,in_buffer,jackd->playing_file,nframes,out_scale,jackd->reverse_endian,
+			  out_unsigned,rbytes);
+  
+
+  if (mainw->record&&prefs->audio_src==AUDIO_SRC_EXT&&mainw->ascrap_file!=-1&&mainw->playing_file>0) {
     mainw->files[mainw->playing_file]->aseek_pos+=rbytes;
+    if (!mainw->record_paused&&mainw->ascrap_file!=mainw->playing_file) mainw->files[mainw->ascrap_file]->aseek_pos+=rbytes;
     jackd->seek_pos+=rbytes;
   }
 
@@ -1108,9 +1147,7 @@ int jack_open_device(jack_driver_t *jackd) {
      just decides to stop calling us. */
   jack_on_shutdown(jackd->client, jack_shutdown, jackd);
 
-  // set process callback and start
-  jack_set_process_callback (jackd->client, audio_process, jackd);  
-
+  jack_set_process_callback ((void *)jackd->client, audio_process, jackd);  
 
   return 0;
 
@@ -1509,9 +1546,8 @@ gint64 lives_jack_get_time(jack_driver_t *jackd, gboolean absolute) {
   // get the time in ticks since either playback started or since last seek
 
   volatile aserver_message_t *msg=jackd->msgq;
-  gdouble frames_written=jackd->frames_written;
+  gdouble frames_written;
 
-  if (frames_written<0.) frames_written=0.;
   if (msg!=NULL&&msg->command==ASERVER_CMD_FILE_SEEK) {
     gboolean timeout;
     int alarm_handle=lives_alarm_set(LIVES_ACONNECT_TIMEOUT);
@@ -1521,6 +1557,10 @@ gint64 lives_jack_get_time(jack_driver_t *jackd, gboolean absolute) {
     if (timeout) return -1;
     lives_alarm_clear(alarm_handle);
   }
+
+  frames_written=jackd->frames_written;
+  if (frames_written<0.) frames_written=0.;
+
   if (jackd->is_output) return jackd->audio_ticks*absolute+(gint64)(frames_written/(gdouble)jackd->sample_out_rate*U_SEC);
   return jackd->audio_ticks*absolute+(gint64)(frames_written/(gdouble)jackd->sample_in_rate*U_SEC);
 }
@@ -1627,6 +1667,8 @@ gboolean jack_try_reconnect(void) {
 
 
 void jack_aud_pb_ready(gint fileno) {
+  // TODO - can we merge with switch_audio_clip()
+
   // prepare to play file fileno
   // - set loop mode
   // - check if we need to reconnect
@@ -1679,7 +1721,6 @@ void jack_aud_pb_ready(gint fileno) {
 	jack_message.command=ASERVER_CMD_FILE_OPEN;
 	jack_message.data=g_strdup_printf("%d",fileno);
 	
-	// TODO ** - use chain messages
 	jack_message.next=NULL;
 	mainw->jackd->msgq=&jack_message;
 	
