@@ -186,6 +186,20 @@ typedef struct {
   GdkScreen *screen;
 } lives_mgeometry_t;
 
+// constant strings
+enum {
+  LIVES_STRING_CONSTANT_ANY=0,
+  LIVES_STRING_CONSTANT_NONE,
+  LIVES_STRING_CONSTANT_RECOMMENDED,
+  LIVES_STRING_CONSTANT_DISABLED,
+  LIVES_STRING_CONSTANT_CL,
+  LIVES_STRING_CONSTANT_BUILTIN,
+  LIVES_STRING_CONSTANT_CUSTOM,
+  LIVES_STRING_CONSTANT_TEST,
+  NUM_LIVES_STRING_CONSTANTS
+};
+
+
 
 /// where do we add the builtin tools in the tools menu
 #define RFX_TOOL_MENU_POSN 2
@@ -258,6 +272,7 @@ typedef struct {
   weed_plant_t *event_list; ///< current event_list, for recording
   weed_plant_t *stored_event_list; ///< stored mt -> clip editor
   gboolean stored_event_list_changed;
+  gboolean stored_event_list_auto_changed;
   gboolean stored_layout_save_all_vals;
   gchar stored_layout_name[PATH_MAX];
 
@@ -332,7 +347,8 @@ typedef struct {
   /// which number file we are playing (or -1)
   gint playing_file;
 
-  gint pre_src_file; ///< file we were editing before any ext input started
+  gint pre_src_file; ///< video file we were playing before any ext input started
+  gint pre_src_audio_file; ///< audio file we were playing before any ext input started
 
   gint scr_width;
   gint scr_height;
@@ -693,8 +709,10 @@ typedef struct {
 
   GdkCursor *cursor;
 
-  weed_plant_t *filter_map;
-  void ***pchains;
+  weed_plant_t *filter_map; // the video filter map for rendering
+  weed_plant_t *afilter_map; // the audio filter map for renering
+  weed_plant_t *audio_event; // event for audio render tracking
+  void ***pchains; // parameter value chains for interpolation
 
   // for the internal player
   GtkWidget *image274;
@@ -880,6 +898,10 @@ typedef struct {
   pthread_mutex_t interp_mutex;  ///< interpolation mutex - parameter interpolation must be single threaded
 
   pthread_mutex_t abuf_mutex;  ///< used to synch audio buffer request count - shared between audio and video threads
+  pthread_mutex_t afilter_mutex;  ///< used to prevent video/gui thread deiniting an audio filter while it may be active
+  pthread_mutex_t data_mutex;  ///< used to prevent data being connected while it is possibly being updated
+
+  volatile lives_rfx_t *vrfx_update;
 
   lives_fx_candidate_t fx_candidates[MAX_FX_CANDIDATE_TYPES]; ///< effects which can have candidates from which a delegate is selected (current examples are: audio_volume, resize)
 
@@ -899,6 +921,8 @@ typedef struct {
   gint rec_signed_endian;
 
   gboolean suppress_dprint; ///< tidy up, e.g. by blocking "switched to file..." and "closed file..." messages
+
+  gchar *string_constants[NUM_LIVES_STRING_CONSTANTS];
   gchar *any_string;  ///< localised text saying "Any", for encoder and output format
   gchar *none_string;  ///< localised text saying "None", for playback plugin name, etc.
   gchar *recommended_string;  ///< localised text saying "recommended", for encoder and output format
@@ -1042,7 +1066,6 @@ typedef struct {
   GtkWidget *drop_frame_button;
   GtkWidget *param_vbox;
   GtkWidget *spinbutton_loops;
-  GtkWidget *trans_entry;
 
   gboolean loop_to_fit;
   gboolean align_start;
