@@ -56,7 +56,7 @@ add_to_special (const gchar *sp_string, lives_rfx_t *rfx) {
   int *ign;
 
   weed_plant_t *param,*paramtmpl,*init_event=NULL;
-  int hint,num_in_tracks=0,error;
+  int num_in_tracks=0,error;
 
   void **pchains=NULL,*pchange;
 
@@ -135,10 +135,9 @@ add_to_special (const gchar *sp_string, lives_rfx_t *rfx) {
 	}
 	if (init_event!=NULL) {
 	  param=weed_inst_in_param((weed_plant_t *)rfx->source,pnum,FALSE);
-	  pchange=pchains[pnum];
 	  paramtmpl=weed_get_plantptr_value(param,"template",&error);
-	  hint=weed_get_int_value(paramtmpl,"hint",&error);
-	  fill_param_vals_to (paramtmpl, (weed_plant_t *)pchange, pnum, hint, num_in_tracks-1);
+	  pchange=pchains[pnum];
+	  fill_param_vals_to ((weed_plant_t *)pchange,paramtmpl,num_in_tracks-1);
 	  weed_set_boolean_array((weed_plant_t *)pchange,"ignore",num_in_tracks,ign);
 	}
       }
@@ -258,7 +257,7 @@ void check_for_special (lives_param_t *param, gint num, GtkBox *pbox, lives_rfx_
       checkbutton = gtk_check_button_new ();
       gtk_widget_set_tooltip_text( checkbutton, (_("Maintain aspect ratio of original frame")));
       eventbox=gtk_event_box_new();
-      gtk_tooltips_copy(eventbox,checkbutton);
+      lives_tooltips_copy(eventbox,checkbutton);
       label=gtk_label_new_with_mnemonic (_("Maintain _Aspect Ratio"));
       
       
@@ -315,6 +314,9 @@ void check_for_special (lives_param_t *param, gint num, GtkBox *pbox, lives_rfx_
       if (!GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET(param->widgets[0]))) gtk_widget_set_sensitive(buttond,FALSE);
 
       g_signal_connect (GTK_FILE_CHOOSER(buttond), "selection-changed",G_CALLBACK (on_fileread_clicked),(gpointer)param->widgets[0]);
+
+      if (GTK_IS_ENTRY(param->widgets[0])) gtk_entry_set_max_length(GTK_ENTRY (param->widgets[0]),PATH_MAX);
+
     }
 
     slist=slist->next;
