@@ -101,6 +101,9 @@ gboolean on_clear_all_clicked (GtkButton *button, gpointer user_data) {
       return FALSE;
     }
 
+  pconx_delete_all();
+  cconx_delete_all();
+
   for (i=0;i<prefs->rte_keys_virtual;i++) {
     if (rte_window!=NULL) gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(key_checks[i]),FALSE);
     for (j=modes-1;j>=0;j--) {
@@ -1019,6 +1022,13 @@ void on_clear_clicked (GtkButton *button, gpointer user_data) {
 
   weed_delete_effectkey (key+1,mode);
 
+  pconx_delete(-1,0,0,key,mode,-1);
+  pconx_delete(key,mode,-1,-1,0,0);
+
+  cconx_delete(-1,0,0,key,mode,-1);
+  cconx_delete(key,mode,-1,-1,0,0);
+
+
   newmode=rte_key_getmode(key+1);
   g_signal_handler_block(mode_radios[key*modes+newmode],mode_ra_fns[key*modes+newmode]);
   rtew_set_mode_radio(key,newmode);
@@ -1028,6 +1038,8 @@ void on_clear_clicked (GtkButton *button, gpointer user_data) {
     idx=key*modes+i;
     gtk_entry_set_text (GTK_ENTRY(combo_entries[idx]),gtk_entry_get_text(GTK_ENTRY(combo_entries[idx+1])));
     type_label_set_text(key,i);
+    pconx_remap_mode(key,i+1,i);
+    cconx_remap_mode(key,i+1,i);
   }
   idx++;
   gtk_entry_set_text (GTK_ENTRY(combo_entries[idx]),"");
@@ -1131,23 +1143,42 @@ static void do_mix_error(void) {
 
 
 
+enum {
+  NAME_TYPE_COLUMN,
+  NAME_COLUMN,
+  HASH_COLUMN,
+  NUM_COLUMNS
+};
 
 
-void fx_changed (GtkItem *item, gpointer user_data) {
+
+void fx_changed (GtkComboBox *combo, gpointer user_data) {
   gint key_mode=GPOINTER_TO_INT(user_data);
   int modes=rte_getmodespk();
   gint key=(gint)(key_mode/modes);
   gint mode=key_mode-key*modes;
-  gchar *hashname1=g_strdup((gchar *)g_object_get_data(G_OBJECT(item),"hashname"));
-  gchar *hashname2=g_strdup((gchar *)g_object_get_data(G_OBJECT(combo_entries[key_mode]),"hashname"));
+
+  GtkTreeIter iter1;
+  GtkTreeModel *model;
+
+  gchar *hashname1;
+  gchar *hashname2=(gchar *)g_object_get_data(G_OBJECT(combo),"hashname");
   gint error;
   gchar *tmp;
 
   int i;
 
+  gchar *txt;
+
+  if (gtk_combo_box_get_active(combo)==-1) return; // -1 is returned after we set our own text (without the type)
+
+  gtk_combo_box_get_active_iter(combo,&iter1);
+  model=gtk_combo_box_get_model(combo);
+
+  gtk_tree_model_get(model,&iter1,HASH_COLUMN,&hashname1);
+
   if (!strcmp(hashname1,hashname2)) {
     g_free(hashname1);
-    g_free(hashname2);
     return;
   }
 
@@ -1167,33 +1198,123 @@ void fx_changed (GtkItem *item, gpointer user_data) {
     gtk_entry_set_text (GTK_ENTRY (combo_entries[key_mode]),(tmp=rte_keymode_get_filter_name(key+1,mode)));
     g_free(tmp);
 
-    // this gets called twice, unfortunately...may be a bug in gtk+
     if (error==-2) do_mix_error();
     if (error==-1) {
       d_print((tmp=g_strdup_printf(_("LiVES could not locate the effect %s.\n"),rte_keymode_get_filter_name(key+1,mode))));
       g_free(tmp);
     }
-    g_free(hashname1);
-    g_free(hashname2);
     return;
   }
 
-  g_object_set_data(G_OBJECT(combo_entries[key_mode]),"hashname",g_strdup(hashname1));
+  // prevents a segfault
+  gtk_combo_box_get_active_iter(combo,&iter1);
+  model=gtk_combo_box_get_model(combo);
 
+  gtk_tree_model_get(model,&iter1,NAME_COLUMN,&txt);
+  gtk_entry_set_text (GTK_ENTRY (combo_entries[key_mode]),txt);
+  g_free(txt);
   g_free(hashname2);
-  g_free(hashname1);
+
+  // TODO - g_free on delete
+  g_object_set_data(G_OBJECT(combo),"hashname",hashname1);
     
   type_label_set_text(key,mode);
 
   check_clear_all_button();
 
+  pconx_delete(-1,0,0,key,mode,-1);
+  pconx_delete(key,mode,-1,-1,0,0);
+
+  cconx_delete(-1,0,0,key,mode,-1);
+  cconx_delete(key,mode,-1,-1,0,0);
+
 }
 
 
 
 
+GtkTreeModel *rte_window_fx_model (void) {
+  GtkTreeStore *tstore;
+
+  GtkTreeIter iter1,iter2;
+
+  // fill names of our effects
+  int fx_idx=0;
+
+  GList *list=name_type_list;
+
+  int error;
+
+  gchar *pkg=NULL,*pkgstring,*fxname;
+
+  tstore=gtk_tree_store_new (NUM_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+
+  while (list!=NULL) {
+    weed_plant_t *filter=get_weed_filter(weed_get_idx_for_hashname((gchar *)g_list_nth_data(hash_list,fx_idx),TRUE));
+    int filter_flags=weed_get_int_value(filter,"flags",&error);
+    if ((weed_plant_has_leaf(filter,"plugin_unstable")&&weed_get_boolean_value(filter,"plugin_unstable",&error)==
+	 WEED_TRUE&&!prefs->unstable_fx)||((enabled_in_channels(filter,FALSE)>1&&
+					    !has_video_chans_in(filter,FALSE))||
+					   (weed_plant_has_leaf(filter,"host_menu_hide")&&
+					    weed_get_boolean_value(filter,"host_menu_hide",&error)==WEED_TRUE)
+					   ||(filter_flags&WEED_FILTER_IS_CONVERTER))) {
+      list = list->next;
+      fx_idx++;
+      continue; // skip audio transitions and hidden entries
+    }
+
+
+    fxname=g_strdup((gchar *)g_list_nth_data(name_list,fx_idx));
+
+    if ((pkgstring=strstr(fxname,": "))!=NULL) {
+      // package effect
+      if (pkg==NULL) {
+	pkg=fxname;
+	fxname=g_strdup(pkg);
+	memset(pkgstring,0,1);
+	/* TRANSLATORS: example " - LADSPA plugins -" */
+	pkgstring=g_strdup_printf(_(" - %s plugins -"),pkg);
+	gtk_tree_store_append (tstore, &iter1, NULL);
+	gtk_tree_store_set(tstore,&iter1,NAME_TYPE_COLUMN,pkgstring,NAME_COLUMN,fxname,
+			 HASH_COLUMN,g_list_nth_data(hash_list,fx_idx),-1);
+	g_free(pkgstring);
+      }
+      gtk_tree_store_append (tstore, &iter2, &iter1);
+      gtk_tree_store_set(tstore,&iter2,NAME_TYPE_COLUMN,list->data,NAME_COLUMN,fxname,
+			 HASH_COLUMN,g_list_nth_data(hash_list,fx_idx),-1);
+    }
+    else {
+      if (pkg!=NULL) g_free(pkg);
+      pkg=NULL;
+      gtk_tree_store_append (tstore, &iter1, NULL);  /* Acquire an iterator */
+      gtk_tree_store_set(tstore,&iter1,NAME_TYPE_COLUMN,list->data,NAME_COLUMN,fxname,
+			 HASH_COLUMN,g_list_nth_data(hash_list,fx_idx),-1);
+      }
+
+    g_free(fxname);
+
+    list = list->next;
+    fx_idx++;
+  }
+
+  if (pkg!=NULL) g_free(pkg);
+
+  return (GtkTreeModel *)tstore;
+}
+
+
+
+
+
+
+
+
+
+
+
+
 GtkWidget * create_rte_window (void) {
-  int i,j,idx,fx_idx,error;
+  int i,j,idx;
 
   gint winsize_h;
   gint winsize_v;
@@ -1220,11 +1341,10 @@ GtkWidget * create_rte_window (void) {
 
   int modes=rte_getmodespk();
 
-  GList *list;
-  GtkWidget *item;
-
   gchar *tmp;
 
+  GtkTreeModel *model;
+
   ///////////////////////////////////////////////////////////////////////////
 
 
@@ -1329,7 +1449,7 @@ GtkWidget * create_rte_window (void) {
     eventbox=gtk_event_box_new();
     gtk_container_add(GTK_CONTAINER(eventbox),label);
     gtk_widget_set_tooltip_text( eventbox, _("Grab keyboard for this effect key"));
-    gtk_tooltips_copy(key_grabs[i],eventbox);
+    lives_tooltips_copy(key_grabs[i],eventbox);
     g_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
 		      G_CALLBACK (label_act_toggle),
 		      key_grabs[i]);
@@ -1410,51 +1530,30 @@ GtkWidget * create_rte_window (void) {
 
       gtk_box_pack_start (GTK_BOX (hbox), nlabels[idx], FALSE, FALSE, 0);
 
-      combo = gtk_combo_new ();
+
+      // create combo entry model
+      model=rte_window_fx_model();
+
+      combo = gtk_combo_box_new_with_model_and_entry (model);
+
+      g_object_set_data (G_OBJECT(combo), "hashname", (gpointer)g_strdup(""));
       gtk_box_pack_start (GTK_BOX (hbox), combo, TRUE, TRUE, 0);
 
-      combo_entries[idx] = GTK_COMBO (combo)->entry;
-      g_object_set_data (G_OBJECT(combo_entries[idx]), "hashname", (gpointer)"");
+      lives_combo_set_entry_text_column(LIVES_COMBO(combo),NAME_TYPE_COLUMN);
 
-      // fill names of our effects
-      fx_idx=0;
-      list=name_type_list;
-      
-      while (list!=NULL) {
-	weed_plant_t *filter=get_weed_filter(weed_get_idx_for_hashname((gchar *)g_list_nth_data(hash_list,fx_idx),TRUE));
-	int filter_flags=weed_get_int_value(filter,"flags",&error);
-	if ((weed_plant_has_leaf(filter,"plugin_unstable")&&weed_get_boolean_value(filter,"plugin_unstable",&error)==
-	     WEED_TRUE&&!prefs->unstable_fx)||((enabled_in_channels(filter,FALSE)>1&&
-						!has_video_chans_in(filter,FALSE))||
-					       (weed_plant_has_leaf(filter,"host_menu_hide")&&
-						weed_get_boolean_value(filter,"host_menu_hide",&error)==WEED_TRUE)
-					       ||(filter_flags&WEED_FILTER_IS_CONVERTER))) {
-	  list = list->next;
-	  fx_idx++;
-	  continue; // skip audio transitions and hidden entries
-	}
-	item = gtk_list_item_new_with_label ((gchar *) list->data);
-	gtk_widget_show(item);
-	gtk_container_add (GTK_CONTAINER (GTK_COMBO(combo)->list), item);
-	g_object_set_data (G_OBJECT(item),"hashname",g_list_nth_data(hash_list,fx_idx));
-	gtk_combo_set_item_string(GTK_COMBO(combo),GTK_ITEM(item),(gchar *)g_list_nth_data(name_list,fx_idx));
-
-	if (fx_idx==rte_keymode_get_filter_idx(i+1,j)) {
-	  g_object_set_data (G_OBJECT(combo_entries[idx]),"hashname",g_list_nth_data(hash_list,fx_idx));
-	}
-
-	g_signal_connect (G_OBJECT(item), "select", G_CALLBACK (fx_changed), GINT_TO_POINTER(idx));
-	list = list->next;
-	fx_idx++;
-      }
+      combo_entries[idx] = lives_combo_get_entry(LIVES_COMBO(combo));
       
       gtk_entry_set_text (GTK_ENTRY (combo_entries[idx]),(tmp=rte_keymode_get_filter_name(i+1,j)));
       g_free(tmp);
+ 
       gtk_entry_set_editable (GTK_ENTRY (combo_entries[idx]), FALSE);
       
       hbox = gtk_hbox_new (FALSE, 12);
       gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
+      g_signal_connect(GTK_OBJECT (combo), "changed",
+		       G_CALLBACK (fx_changed),GINT_TO_POINTER(i*rte_getmodespk()+j));
+      
       g_signal_connect (GTK_OBJECT (info_buttons[idx]), "clicked",
 			G_CALLBACK (on_rte_info_clicked),GINT_TO_POINTER (idx));
 
@@ -1625,6 +1724,7 @@ void redraw_pwindow (gint key, gint mode) {
       // rip out the contents
       if (mainw->invis==NULL) mainw->invis=gtk_vbox_new(FALSE,0);
       child_list=gtk_container_get_children(GTK_CONTAINER(lives_dialog_get_content_area(GTK_DIALOG(fx_dialog[1]))));
+      gtk_container_set_focus_child(GTK_CONTAINER(GTK_DIALOG(fx_dialog[1])->action_area),NULL);
       for (i=0;i<g_list_length(child_list);i++) {
 	GtkWidget *widget=(GtkWidget *)g_list_nth_data(child_list,i);
 	if (widget!=GTK_DIALOG (fx_dialog[1])->action_area) {
@@ -1636,6 +1736,7 @@ void redraw_pwindow (gint key, gint mode) {
       if (child_list!=NULL) g_list_free(child_list);
       on_paramwindow_cancel_clicked(NULL,NULL);
       restore_pwindow(rfx);
+
     }
   }
 }
@@ -1702,7 +1803,7 @@ void rte_set_key_defs (GtkButton *button, lives_rfx_t *rfx) {
 
 void rte_set_defs_ok (GtkButton *button, lives_rfx_t *rfx) {
   int i;
-  weed_plant_t **ptmpls,*filter,*copy_param=NULL;
+  weed_plant_t **ptmpls,*filter;
   int error;
   lives_colRGB24_t *rgbp;
 
@@ -1715,9 +1816,7 @@ void rte_set_defs_ok (GtkButton *button, lives_rfx_t *rfx) {
       switch (rfx->params[i].type) {
       case LIVES_PARAM_COLRGB24:
 	rgbp=(lives_colRGB24_t *)rfx->params[i].value;
-	if (rfx->params[i].copy_to!=-1) copy_param=weed_inst_in_param((weed_plant_t *)rfx->source,
-								      rfx->params[i].copy_to,FALSE);
-	update_weed_color_value(ptmpls[i],i,copy_param,rgbp->red,rgbp->green,rgbp->blue,0);
+	update_weed_color_value(ptmpls[i],i,rgbp->red,rgbp->green,rgbp->blue,0);
 	break;
       case LIVES_PARAM_STRING:
 	weed_set_string_value(ptmpls[i],"host_default",(gchar *)rfx->params[i].value);
